@@ -11,7 +11,7 @@ def testUpdateAndSearch()
     doc.add_text("Somewhere over the rainbow.  Way up high.")
     wfd = defer.waitForDeferred(node.put_doc(doc))
     yield wfd
-    print wfd.getResult()
+    print(wfd.getResult())
 
     cond = hyperestraier.Condition()
     cond.set_phrase("rainbow AND lullaby")
@@ -20,12 +20,12 @@ def testUpdateAndSearch()
     nres = wfd.getResult()
     if nres:
         for rdoc in nres.docs:
-            print "#" * 20
+            print("#" * 20)
             v = rdoc.attr("@uri")
-            print "URI: " + v
+            print("URI: " + v)
             v = rdoc.attr("@title")
-            print "TITLE: " + v
-            print rdoc.snippet
+            print("TITLE: " + v)
+            print(rdoc.snippet)
 
 node = hyperestraier.Node(hyperestraier.AysnTransport())
 node.set_url("http://localhost:1978/node/test")
