@@ -12,7 +12,7 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.9'
+__version__  = '0.10.10'
 __author__ = "Hiroki Ohtani (liris.pp [at] gmail.com)"
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
 __license__ = "LGPL"
@@ -420,7 +420,7 @@ class Transport(object):
         result = response.read()
         code = response.code
         
-        return code, result.decode("utf-8")
+        return code, result.decode("utf-8", "replace")
 
 try:
     from twisted.internet import defer, reactor
